@@ -18,6 +18,7 @@ from hcube.api.models.aggregation import (
 from hcube.api.models.cube import Cube
 from hcube.api.models.dimensions import (
     ArrayDimension,
+    BooleanDimension,
     DateDimension,
     DateTimeDimension,
     Dimension,
@@ -91,6 +92,7 @@ class ClickhouseCubeBackend(CubeBackend):
         (IntMetric, "Int"),
         (IPv4Dimension, "IPv4"),
         (IPv6Dimension, "IPv6"),
+        (BooleanDimension, "Bool"),
     )
     default_settings = {}
 
